.. Ciceroscm documentation master file, created by
   sphinx-quickstart on for openscm-runner onThu Mar 19 12:35:34 2020.
   And adapted 07.01.2022 to ciceroscm
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

CiceroSCM
==============

.. include:: ../../README.rst
    :start-after: sec-begin-license
    :end-before: sec-end-license

.. toctree::
    :maxdepth: 2
    :caption: Documentation

    usage
    development

.. toctree::
    :maxdepth: 2
    :caption: API reference

    ciceroscm
    upwelling_diffusion_model
    concentrations_emissions_handler
    input_handler
    perturbations
    make_plots

.. toctree::
    :maxdepth: 2
    :caption: Versions

    changelog

Index
-----

- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`
